@@ -1,16 +1,26 @@
 #!/bin/bash
 source lfs-install.conf
-source lfs-install_chapter3.func
-source lfs-install_chapter4.func
-source lfs-install_chapter5.func
-source lfs-install_chapter6.func
-source lfs-install_chapter7.func
-source lfs-install_chapter8.func
-source lfs-install_chapter9.func
-source lfs-install_cdrom.func
+for i in *.func; do source $i; done
 
 function main
 {
+	# test if the user is root
+	if [ ! $UID = 0 ]
+	then
+		echo 'Error: no permission (user is not root)'
+		exit 1
+	fi
+
+	# test if it is already running
+	if [ -e /var/lock/lfs-install.lock ]
+	then
+		echo 'Error: process locked (lfs-install is already running)'
+		exit 1
+	fi
+        # manage the lock file
+	trap 'test -e /var/lock/lfs-install.lock && rm -f /var/lock/lfs-install.lock; exit 0' 0 2 15
+	touch /var/lock/lfs-install.lock
+
 	# lfs chapter 4
 	creating_partition
 	creating_filesystem
@@ -45,9 +55,9 @@ function main
 	configure_packages3
 
 	# lfs-install cdrom
-	echo -n "Build cdrom: "
+	echo -n 'Build cdrom: '
 	read cdrom
-	if [ "$cdrom" == "y" ]
+	if [ $cdrom = y ]
 	then
 		build_cdrom
 	else
